/*
	This do file constructs measures of the Bartik shock at the commuting zone level. 
	See formula for Bartik shock in the main text.
	
	Last edited: November 21, 2017
	
*/

set more off
clear all

*Define Directories
local dir "..." //Insert your directory path
local cbpdir "`dir'/AGNR-JobFlowsChinaShock/data/cbp/"
local netsdir "`dir'/AGNR-JobFlowsChinaShock/data/nets/"
local bartikdir "`dir'/AGNR-JobFlowsChinaShock/data/bartik/"

**CBP employment totals across commuting zones
use "`cbpdir'/emp_counts/cbp_czone_emp_total.dta", clear
rename emp cbp_emp
keep if year > 1991

collapse(sum) cbp_emp, by(year czone)

rename cbp_emp cbp_czone_emp
tempfile cbp_czone_emp_total
save `cbp_czone_emp_total'

**CBP employment totals across industries
use "`cbpdir'emp_counts/cbp_czone_emp_total.dta", clear
rename emp cbp_emp
keep if year > 1991

collapse(sum) cbp_emp, by(year sic87dd)

rename cbp_emp cbp_sic_emp
tempfile cbp_sic_emp_total
save `cbp_sic_emp_total'

**NETS employment totals across commuting zones
use "`netsdir'emp_counts/nets_czone_emp_total.dta", clear
keep if year < 2012

collapse(sum) nets_emp, by(year czone)

rename nets_emp nets_czone_emp
tempfile nets_czone_emp_total
save `nets_czone_emp_total'

**NETS employment totals across industries
use "`netsdir'emp_counts/nets_czone_emp_total.dta", clear
keep if year < 2012

collapse(sum) nets_emp, by(year sic87dd)

rename nets_emp nets_sic_emp
tempfile nets_sic_emp_total
save `nets_sic_emp_total'


****generating bartik variables****
****CBP****
use "`cbpdir'emp_counts/cbp_czone_emp_total.dta", clear
rename emp cbp_emp
keep if year > 1991

merge m:1 year czone using `cbp_czone_emp_total', nogenerate
merge m:1 year sic87dd using `cbp_sic_emp_total', nogenerate

egen czonesic=group(czone sic87dd)
tsset czonesic year

gen cbp_emp_exc = cbp_sic_emp - cbp_emp

foreach i in "7" "8" "12"{

	gen cbp_emp_exc_`i' = L`i'.cbp_sic_emp - L`i'.cbp_emp

}

foreach i in "7" "8" "12"{

	gen ratio_`i' = L`i'.cbp_emp/L`i'.cbp_czone_emp

}

foreach i in "7" "8" "12"{

gen cbp_bartik_`i' = ratio_`i' * ((cbp_emp_exc - cbp_emp_exc_`i')/ cbp_emp_exc_`i')

}

collapse(sum) cbp_bartik* cbp_emp, by(year czone)

tempfile cbp_bartik
save `cbp_bartik'


****NETS****
use "`netsdir'emp_counts/nets_czone_emp_total.dta", clear
keep if year < 2012

merge m:1 year czone using `nets_czone_emp_total', nogenerate
merge m:1 year sic87dd using `nets_sic_emp_total', nogenerate

egen czonesic=group(czone sic87dd)
tsset czonesic year

gen nets_emp_exc = nets_sic_emp - nets_emp

foreach i in "7" "8" "12"{

	gen nets_emp_exc_`i' = L`i'.nets_sic_emp - L`i'.nets_emp

}

foreach i in "7" "8" "12"{

	gen ratio_`i' = L`i'.nets_emp/L`i'.nets_czone_emp

}

foreach i in "7" "8" "12"{

gen nets_bartik_`i' = ratio_`i' * ((nets_emp_exc - nets_emp_exc_`i')/ nets_emp_exc_`i')

}

collapse(sum) nets_bartik* nets_emp, by(year czone)

tempfile nets_bartik
save `nets_bartik'

use `cbp_bartik', clear
merge 1:1 year czone using `nets_bartik', nogenerate
drop nets_emp cbp_emp

foreach b in "cbp" "nets" {
	foreach t in "7" "8" "12"{
		label var `b'_bartik_`t' "`b'-adjusted Bartik shock; `t' year change"
	}
}


save "`bartikdir'bartik_variables.dta", replace

