*************************************************************************
/* APPENDIX B FIGURE 3: Net employment changes by industry  */

* Last edited : November 21, 2017
**************************************************************************

set more off
clear all

*Define directories
local dir "..." //Insert your directory path
local outdir "`dir'/AGNR-JobFlowsChinaShock/out/"
local datadir "`dir'/AGNR-JobFlowsChinaShock/data/sample/"




foreach sample in "a" "b" {
	
	*Load dataset
	use  "`datadir'main_industry.dta", clear

	*keeping only the 3 year differences
	keep year sic87dd *empchange_3 nets_emp_total nets_empchange_total

	*keeping only manufacturing (sample a) or non-manufacturing (sample b) industries
	if "`sample'" == "a" {
		drop if sic87dd < 2000
		drop if sic87dd > 3999
	}
	
	else if "`sample'" == "b" {
		drop if sic87dd >= 2000 & sic87dd <= 4000
	}
	
	collapse(sum) nets*, by(year)

	gen nets_emp_total_initial = nets_emp_total - nets_empchange_total

	gen net_expansions = nets_exp_empchange_3 + nets_con_empchange_3

	gen net_births = nets_birth_empchange_3 + nets_death_empchange_3

	drop if year < 1995

	rename nets_birth_empchange_3 birth
	rename nets_death_empchange_3 death
	rename nets_exp_empchange_3 expansion
	rename nets_con_empchange_3 contraction
	rename nets_empchange_total net_creation

	gen creation = expansion + birth
	gen destruction = contraction + death
	gen destruction_abs = -destruction

	*absolute values
	gen death_abs = -death
	gen contraction_abs = -contraction
	gen expansion_share = expansion/creation

	*shares
	gen birth_share = birth/creation
	gen contraction_share = contraction/destruction
	gen death_share = death/destruction 

	*values in millions
	replace creation = creation/1000000
	replace expansion = expansion/1000000
	replace birth = birth/1000000
	replace death_abs = death_abs/1000000
	replace destruction_abs = destruction_abs/1000000
	replace contraction_abs = contraction_abs/1000000
	replace net_expansions = net_expansions/1000000
	replace net_births = net_births/1000000
	replace net_creation = net_creation/1000000

	format creation %9.0fc
	format expansion %9.0fc
	format destruction_abs %9.0fc
	format contraction_abs %9.0fc
	format net_creation %9.0fc
	format net_expansions %9.0fc
	format net_births %9.0fc

	label define cat 1996 "1993-1996" 1997 "1994-1997" 1998 "1995-1998" 1999 "1996-1999" 2000 "1997-2000" 2001 "1998-2001" 2002 "1999-2002" 2003 "2000-2003" 2004 "2001-2004" 2005 "2002-2005" 2006 "2003-2006" 2007 "2004-2007" 2008 "2005-2008"  2009 "2006-2009" 2010 "2007-2010" 2011 "2008-2011"
	label values year cat

	twoway (line net_expansions year, lp(longdash) lw(medthick) lc(red)) (line net_births year, lw(medthick) lp(shortdash) lc(blue)) (line net_creation year, lp(solid) lw(medthick) lc(black)), legend(lab(1 "Expansions-Contractions") lab(2 "Births-Deaths") lab(3 "Net Job Creation")) xtitle("") scheme(s1color) xlabel(1996 1999 2002 2005 2008 2011 , valuelabel) yline(0, lw(thin) lc(black)) ytitle("Millions")
	gr export "`outdir'appb_fig3`sample'.eps", replace
}
