*************************************************************************
/* APPENDIX C TABLE 9: Estimation of the Effects of the China's PNTR Status
on U.S. Commuting Zones by Sectoral Employment (1992-2011)
THE FIRST THREE COLUMNS CORRESPOND TO THE PNTR COEFFICIENTS 
AND THE LAST THREE CORRESPOND TO THE BARTIK COEFFICIENTS */

* Last edited : November 21, 2017
**************************************************************************

set more off
set matsize 1000
clear all


*Define directories
local dir "..."
local outdir "`dir'/AGNR-JobFlowsChinaShock/out/"
local datadir "`dir'/AGNR-JobFlowsChinaShock/data/sample/"
local bartikdir "`dir'/AGNR-JobFlowsChinaShock/data/bartik/"
local popestdir "`dir'/AGNR-JobFlowsChinaShock/data/popest/"
local xwalksdir "`dir'/AGNR-JobFlowsChinaShock/xwalks/"
local controls "`dir'/AGNR-JobFlowsChinaShock/data/controls/"
local pntrdir "`dir'/AGNR-JobFlowsChinaShock/data/pntr/"


*Load dataset
use "`datadir'main_czone.dta", clear

*merge bartik varaibles
merge m:1 year czone using "`bartikdir'bartik_variables.dta", nogenerate

*get annualized Bartik variables
foreach b in "cbp" "nets" {
	foreach t in "7" "8" "12"{
		replace `b'_bartik_`t'=(100/`t')*`b'_bartik_`t'
	}
}

*Merge PNTR data
merge m:1 czone year using "`pntrdir'clean/spread_czone.dta", nogenerate

*Merge population data
merge m:1 czone year using "`popestdir'czone_pop_1990_2012_AADHP.dta", nogenerate
keep if year > 1990
keep if year < 2012

*Merge regional data
* Region dummies
merge m:1 czone using "`xwalksdir'geo/cw_czone_region_AADHP.dta" , assert(2 3) keep(3) keepusing(region) nogenerate
tab region, gen(region)

*Manufacturing shares
merge m:1 czone year using "`controls'mfgsh.dta", keep(3) nogenerate

*Specifying panel
tsset, clear
gen czone_class=string(czone)+string(class)
destring czone_class, replace

tsset czone_class year
sort czone_class year

*Preparing employment variables
*NETS does not have data for 1991
replace nets_emp=. if year==1991

foreach b in "cbp" "nets" {

	*no zeros or missing values
	replace `b'_emp=1 if `b'_emp==0
	replace `b'_emp=1 if `b'_emp==. & year>1991

		foreach t in "7" "8" "12"{
			gen d_`b'_emp_`t'=(`b'_emp-L`t'.`b'_emp)*100/(`t'*L`t'.`b'_emp)
		}
}

*base year employment variables
foreach b in "cbp" "nets" {
	gen `b'_emp1992=`b'_emp
	replace `b'_emp1992=F.`b'_emp1992 if year==1991
		
		forvalues i = 1993/2012 {
			replace `b'_emp1992=L.`b'_emp1992 if year==`i'
		}
}
		
gen cbp_emp1991=cbp_emp
	forvalues i = 1992/2012 {
		replace cbp_emp1991=L.cbp_emp1991 if year==`i'
	}

gen pop1991=totpop
	forvalues i = 1992/2012 {
		replace pop1991=L.pop1991 if year==`i'
	}
	
gen pop1992=totpop
replace pop1992=F.pop1992 if year==1991
	forvalues i = 1993/2012 {
		replace pop1992=L.pop1992 if year==`i'
	}

	
*Employment to working age population ratios	
foreach b in "cbp"  "nets" {
	gen `b'_emppop = 100 * (`b'_emp/workagepop)		

		foreach t in "7" "8" "12"{
			gen d_`b'_emppop_`t' =d_`b'_emp_`t'*(L`t'.`b'_emp/((L`t'.workagepop+workagepop)/2))	
		}
}



*Preparing Job Flows data
foreach b in  "nets" {
	foreach t in 7 8 12 {
		foreach f in "birth" "exp"  {
		
			replace `b'_`f'_empchange_`t'=. if year==1991+`t'
			replace `b'_`f'_empchange_`t'=0 if `b'_`f'_empchange_`t'==. & year>1991+`t'
			*changes
			gen d_`b'_`f'_`t'=`b'_`f'_empchange_`t'*100/(`t'*L`t'.`b'_emp)
			*employment to population
			gen d_`b'_`f'pop_`t'=d_`b'_`f'_`t'*(L`t'.`b'_emp/((L`t'.workagepop+workagepop)/2))
		
		}
		
		foreach f in "death"  "con" {
			replace `b'_`f'_empchange_`t'=. if year==1991+`t'
			replace `b'_`f'_empchange_`t'=0 if `b'_`f'_empchange_`t'==. & year>1991+`t'
			*changes
			gen d_`b'_`f'_`t'=-`b'_`f'_empchange_`t'*100/(`t'*L`t'.`b'_emp)
			*employment to population
			gen d_`b'_`f'pop_`t'=d_`b'_`f'_`t'*(L`t'.`b'_emp/((L`t'.workagepop+workagepop)/2))
		}
		
		*extensive margin
		gen d_`b'_ext_`t'=d_`b'_birth_`t'-d_`b'_death_`t' 
		*intensive margin
		gen d_`b'_int_`t'=d_`b'_exp_`t'-d_`b'_con_`t' 
		*job creation
		gen d_`b'_cre_`t'=d_`b'_birth_`t'+d_`b'_exp_`t' 
		*job destruction
		gen d_`b'_des_`t'=d_`b'_death_`t'+d_`b'_con_`t' 
		
		*employment to population 
		gen d_`b'_extpop_`t'=d_`b'_birthpop_`t'-d_`b'_deathpop_`t'
		gen d_`b'_intpop_`t'=d_`b'_exppop_`t'-d_`b'_conpop_`t'
		gen d_`b'_crepop_`t'=d_`b'_birthpop_`t'+d_`b'_exppop_`t'
		gen d_`b'_despop_`t'=d_`b'_deathpop_`t'+d_`b'_conpop_`t'
	}
}

*Generate YEAR and SECTOR-YEAR DUMMIES (about 210 of them)
gen classyear=class*year
qui tab classyear, gen(classyeard)
qui tab class, gen(classd)

*Regressors and instruments
forvalues i=1/3 {
	foreach k in "import_cz"  {

		foreach t in 7 8 12 {
			foreach h in "cbp" "nets" {
			gen d_`h'_`k'_usch_`t'_c`i'=d_`h'_`k'_usch_`t'*classd`i'
			gen d_`h'_`k'_otch_`t'_c`i'=d_`h'_`k'_otch_`t'*classd`i'
			}
		}
	}
	
	foreach b in "cbp" "nets" {
		gen `b'_mfgsh_c`i'=`b'_mfgsh*classd`i'
	foreach t in 7 8 12 {
			gen `b'_bartik_`t'_c`i'=`b'_bartik_`t'*classd`i'
		}
	}
	
	foreach k in "spread_cz"  {
		foreach t in 7 8 12 {
			foreach b in "cbp" "nets"{
				gen `b'_`k'_`t'_c`i'=`b'_`k'_`t'*classd`i'
			}
		}
	}
	
	forvalues j=1/9 {
		gen region`j'_c`i'=region`j'*classd`i'
	}	

}

estimates clear

**************generating conditions and controls*******************************
	local window9211 year==1999 | year==2011

    * Weighting, clustering, and controls
    local aw "[aw = pop1992]"
    local options "noconstant vce(cluster czone)"
    local time_effects classyeard*
    local region_effects region1_* region2_* region3_* region4_* region5_* region6_* region7_* region8_* region9_*


	*Factors needed to rescale coefficients (to undo multiplication by 100 and also annualization)
	gen lambda_9211 = 100/(2011 - 1992) 
	gen lambda_9299 = 100/(1999 - 1992)
	gen lambda_9911 = 100/(2011 - 1999)


	*End-of-period working age population
	gen workage_2011 = workagepop if year == 2011
	forvalues i = 2010(-1)1992{
		replace workage_2011 = F.workage_2011 if year == `i'
	}

 *Creating stacked variables for 1992-1999, 1999-2011
 foreach f in "cbp_emp" "nets_emp" "nets_birth" "nets_death" "nets_exp" "nets_con" "nets_ext" "nets_int" "nets_cre" "nets_des" {

	  gen d_`f'pop_9211=d_`f'pop_12
	  replace d_`f'pop_9211=d_`f'pop_7 if year==1999
	    
  }


  forvalues i=1/3 {
	  foreach b in "cbp" "nets" {
			foreach k in "import_cz"  {
		   
				 gen d_`b'_`k'_usch_9211_c`i'=d_`b'_`k'_usch_12_c`i'
				 gen d_`b'_`k'_otch_9211_c`i'=d_`b'_`k'_otch_12_c`i'
				  
				 replace d_`b'_`k'_usch_9211_c`i'=d_`b'_`k'_usch_7_c`i' if year==1999
				 replace d_`b'_`k'_otch_9211_c`i'=d_`b'_`k'_otch_7_c`i' if year==1999
				 
		  }
	  }
	  
	  
	foreach k in "spread_cz"  {
		foreach b in "cbp" "nets" {
			gen `b'_`k'_9211_c`i'=`b'_`k'_12_c`i'  
			replace `b'_`k'_9211_c`i'=`b'_`k'_7_c`i' if year==1999
  }
  }

	  foreach b in "cbp" "nets" {
	  
		  gen `b'_mfgsh_9211_c`i'=L12.`b'_mfgsh_c`i'
		  replace `b'_mfgsh_9211_c`i'=L7.`b'_mfgsh_c`i' if year==1999
		  		  
		  gen `b'_bartik_9211_c`i'=`b'_bartik_12_c`i'
		  replace `b'_bartik_9211_c`i'=`b'_bartik_7_c`i' if year==1999
	  }
 }       
 
   foreach b in "cbp" "nets" {
  
	  gen `b'_bartik_9211=`b'_bartik_12
	  replace `b'_bartik_9211=`b'_bartik_7 if year==1999
	  
  }


 ***REGRESSIONS and Calculations of Predicted Employment Losses

    *Main regressor and instruments
    local instruments d_nets_import_cz_otch_9211_c1 d_nets_import_cz_otch_9211_c2 d_nets_import_cz_otch_9211_c3
    local mfgsh_effects nets_mfgsh_9211_*   
	local bartik nets_bartik_9211_c*

				 
* Regressions with NETS total employment				 
*Partial R-squared factor used to "discount" implied employment changes
gen pfactor = 0.66
*Interquartile range of NTR gap distribution
gen iqr_nets = 0.057 - 0.019
gen iqr_cbp = 0.072 - 0.025 

local bb "nets"
foreach f in "emp" {

     * Dependent variable
	local yvar d_`bb'_`f'pop_9211
	local shocks `bb'_spread_cz_9211_c1 `bb'_spread_cz_9211_c2 `bb'_spread_cz_9211_c3
				 					
		eststo m2_`f':regress `yvar' `shocks' `bartik' `time_effects' `mfgsh_effects' `region_effects'  `aw' if `window9211', `options'

	forvalues i = 1/3 {	
		gen pred = _b[nets_spread_cz_9211_c`i'] * iqr_nets
		sum pred
		drop pred
	}
}

* Regressions with Job Flows
local bb "nets"
foreach f in  "birth" "death" "exp" "con" "ext" "int" "cre" "des" {


	local yvar d_`bb'_`f'pop_9211  
	local shocks `bb'_spread_cz_9211_c1 `bb'_spread_cz_9211_c2 `bb'_spread_cz_9211_c3
	
	eststo m2_`f':ivregress 2sls `yvar' `shocks' `bartik' `time_effects' `mfgsh_effects' `region_effects' `aw' if `window9211', `options'

	forvalues i = 1/3 {	
		gen pred = _b[nets_spread_cz_9211_c`i'] * iqr_nets
		sum pred
		drop pred
	}

}

*Regressions with CBP data
local bb "cbp"
replace pfactor=0.6

foreach f in "emp"  {

	local yvar d_`bb'_`f'pop_9211
	local shocks `bb'_spread_cz_9211_c1 `bb'_spread_cz_9211_c2 `bb'_spread_cz_9211_c3
    local instruments d_cz_otch_9211_c1 d_cz_otch_9211_c2 d_cz_otch_9211_c3
    local mfgsh_effects cbp_mfgsh_9211_* 
	local bartik cbp_bartik_9211_c*

	eststo m2_`bb':regress `yvar' `shocks' `bartik' `time_effects' `mfgsh_effects' `region_effects' `aw' if `window9211', `options'

	forvalues i = 1/3 {	
		gen pred = _b[cbp_spread_cz_9211_c`i'] * iqr_cbp
		sum pred
		drop pred
	}

}



**export results
foreach f in "emp" "birth" "death" "exp" "con" "ext" "int" "cre" "des" {

	esttab m2_`f' using "`outdir'appc_tab9.csv", b(%9.2f) se(%9.2f) star(* .10 ** .05 *** .01) replace
	insheet using "`outdir'appc_tab9.csv", comma clear
	export excel "`outdir'appc_tab9.xlsx", sheetreplace sheet(appc_tab9_`f')

}

foreach bb in "cbp" {

	esttab m2_`bb' using "`outdir'appc_tab9.csv", b(%9.2f) se(%9.2f) star(* .10 ** .05 *** .01) replace
	insheet using "`outdir'appc_tab9.csv", comma clear
	export excel "`outdir'appc_tab9.xlsx", sheetreplace sheet(appc_tab9_`bb')

}

